=========================
ACCESS-NRI Intake Catalog
=========================

**Tools and configuration info used to manage ACCESS-NRI's intake catalog**

Read the `documentation here <https://access-nri-intake-catalog.readthedocs.io/en/latest/index.html>`_. 

------------

+---------------+----------------------+
| Documentation | |docs|               |
+---------------+----------------------+
| Package       | |pypi| |conda|       |
+---------------+----------------------+
| CI/CD         | |ci| |cd|            |
+---------------+----------------------+
| Development   | |codecov| |black|    |
+---------------+----------------------+
| License       | |license|            |
+---------------+----------------------+

.. |docs| image:: https://readthedocs.org/projects/access-nri-intake-catalog/badge/?version=latest
    :target: https://access-nri-intake-catalog.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
        
.. |pypi| image:: https://img.shields.io/pypi/v/access-nri-intake
        :target: https://pypi.org/project/access-nri-intake/
        :alt: PyPI package
        
.. |conda| image:: https://img.shields.io/conda/v/accessnri/access-nri-intake
        :target: https://anaconda.org/accessnri/access-nri-intake
        :alt: Conda package

.. |ci| image:: https://github.com/ACCESS-NRI/access-nri-intake-catalog/actions/workflows/ci.yml/badge.svg
        :target: https://github.com/ACCESS-NRI/access-nri-intake-catalog/actions/workflows/ci.yml
        :alt: Package CI status
        
.. |cd| image:: https://github.com/ACCESS-NRI/access-nri-intake-catalog/actions/workflows/cd.yml/badge.svg
        :target: https://github.com/ACCESS-NRI/access-nri-intake-catalog/actions/workflows/cd.yml
        :alt: Package CD status

.. |codecov| image:: https://codecov.io/gh/ACCESS-NRI/access-nri-intake-catalog/branch/main/graph/badge.svg?token=DAC1NK32LM
        :target: https://codecov.io/gh/ACCESS-NRI/access-nri-intake-catalog
        :alt: Code test coverage
        
.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/python/black
        :alt: Black code formatter
        
.. |license| image:: https://img.shields.io/github/license/ACCESS-NRI/intake-dataframe-catalog
        :target: https://github.com/ACCESS-NRI/intake-dataframe-catalog/blob/main/LICENSE
        :alt: Apache-2.0 License
